@@ -2,7 +2,7 @@
 package MRTG_lib;
 
 ###################################################################
-# MRTG 2.10.9  Support library MRTG_lib.pm
+# MRTG 2.10.12  Support library MRTG_lib.pm
 ###################################################################
 # Created by Tobias Oetiker <oetiker@ee.ethz.ch>
 #            and Dave Rand <dlr@bungi.com>
@@ -67,17 +67,17 @@ $VERSION = 2.100001;
        [sub{$_[0] && (-d $_[0] )}, sub{"Log directory $_[0] does not exist"}],
 
        'forks' =>
-       [sub{$_[0] && (int($_[0]) > 0 && $MRTG_lib::OS eq 'UNIX')},
+       [sub{$_[0] && (int($_[0]) > 0 and $MRTG_lib::OS eq 'UNIX')},
         sub{"Less than 1 fork or not running on Unix/Linux"}],
 
        'refresh' => 
        [sub{int($_[0]) >= 300}, sub{"$_[0] should be 300 seconds or more"}],
 
        'enableipv6' =>
-       [sub{((lc($_[0])) eq 'yes' || (lc($_[0])) eq 'no')}, sub{"$_[0] must be yes or no"}],
+       [sub{((lc($_[0])) eq 'yes' or (lc($_[0])) eq 'no')}, sub{"$_[0] must be yes or no"}],
 
        'interval' => 
-       [sub{int($_[0]) >= 1 && int($_[0]) <= 60}, sub{"$_[0] should be at least 1 Minute and no more than 60 Minutes"}], 
+       [sub{int($_[0]) >= 1 and int($_[0]) <= 60}, sub{"$_[0] should be at least 1 Minute and no more than 60 Minutes"}], 
 
        'writeexpires' =>  
        [sub{1}, sub{"Internal Error"}],
@@ -115,6 +115,10 @@ $VERSION = 2.100001;
        'runasdaemon' =>
        [sub{1}, sub{"Internal Error"}],
 
+       'maxage' =>
+       [sub{(($_[0] =~ /^[0-9]+$/) and ($_[0] > 0)) },
+        sub{"$_[0] must be a Number bigger than 0"}],
+
        'nospacechar' =>
        [sub{length($_[0]) == 1}, sub{"$_[0] must be one character long"}],
 
@@ -148,7 +152,7 @@ $VERSION = 2.100001;
         sub{"$_[0] must a number bigger than 0"}],
 
        'ipv4only[]' =>
-       [sub{((lc($_[0])) eq 'yes' || (lc($_[0])) eq 'no')}, sub{"$_[0] must be yes or no"}],
+       [sub{((lc($_[0])) eq 'yes' or (lc($_[0])) eq 'no')}, sub{"$_[0] must be yes or no"}],
 
        'absmax[]' => 
        [sub{($_[0] =~ /^[0-9]+$/)}, sub{"$_[0] must be a Number"}],
@@ -396,7 +400,7 @@ sub readcfg ($$$$;$$) {
                 $$rcfg{$first}{$second} = $post{$first};
                 delete $defaulted{$first}{$second};
             } else {
-                $$rcfg{$first}{$second} .= ( defined $$cfg{nospacechar} && $post{$first} =~ /(.*)\Q$$cfg{nospacechar}\E$/) ? $1 : " ".$post{$first} ;
+                $$rcfg{$first}{$second} .= ( defined $$cfg{nospacechar} and $post{$first} =~ /(.*)\Q$$cfg{nospacechar}\E$/) ? $1 : " ".$post{$first} ;
             }
         }
 
@@ -566,7 +570,7 @@ sub cfgcheck ($$$$) {
 
     if (defined $$cfg{workdir}) {
         die ("ERROR: WorkDir must not contain spaces when running on Windows. (Yeat another reason to get Linux)\n")
-                if ($OS eq 'NT' || $OS eq 'OS2') and $$cfg{workdir} =~ /\s/;
+                if ($OS eq 'NT' or $OS eq 'OS2') and $$cfg{workdir} =~ /\s/;
         ensureSL(\$$cfg{workdir});
         $$cfg{logdir}=$$cfg{htmldir}=$$cfg{imagedir}=$$cfg{workdir};
         if (not -d $$cfg{workdir}){
@@ -643,7 +647,7 @@ sub cfgcheck ($$$$) {
      $$cfg{logformat} = 'rateup' unless defined $$cfg{logformat};
 
     if($$cfg{logformat} eq 'rrdtool') {
-        my $name = ($MRTG_lib::OS eq 'NT' || $MRTG_lib::OS eq 'OS2')? 'rrdtool.exe':'rrdtool';
+        my $name = ($MRTG_lib::OS eq 'NT' or $MRTG_lib::OS eq 'OS2')? 'rrdtool.exe':'rrdtool';
         foreach my $path (split /\Q${MRTG_lib::PS}\E/, $ENV{PATH}) {
             ensureSL(\$path);
             -f "$path$name" && do { 
@@ -1663,7 +1667,7 @@ RRD
 </rrd>
 RRD
         
-    if ( $OS eq 'NT'  || $OS eq 'OS2') {
+    if ( $OS eq 'NT'  or $OS eq 'OS2') {
        open (R, "|$$cfg{rrdtool} restore - $$cfg{logdir}$$rcfg{'directory'}{$router}$router.rrd");
     } else {
        open (R, "|-") or exec "$$cfg{rrdtool}","restore","-","$$cfg{logdir}$$rcfg{'directory'}{$router}$router.rrd";
@@ -1887,7 +1891,7 @@ The target config hash has the structure
 
  $targetcfg{configoption}{targetname} = 'value'
 
-See L<reference> for more information about the MRTG configuration syntax.
+See L<mrtg-reference> for more information about the MRTG configuration syntax.
 
 C<readcfg> can take two additional arguments to extend the config file
 syntax. This allows programs to put their configuration into the mrtg config
