@@ -1,5 +1,5 @@
 /*
- MRTG 2.10.7  -- Rateup
+ MRTG 2.10.12  -- Rateup
  *********************
 
  Rateup is a fast add-on to the great MRTG Traffic monitor.  It makes
@@ -54,15 +54,18 @@
 /* MSVCRT.DLL does not know %ll in printf */ 
 #ifdef __MINGW32_VERSION
 #define LLD "%I64d"
+#define LLD_FORMAT "I64d"
 #endif
 
 #ifdef __EMX__  /* OS/2 */
 #define strtoll _strtoll
 #define LLD "%Ld" /* EMX lib use %Ld for long long */
+#define LLD_FORMAT "Ld"
 #endif
 
 #ifndef LLD
 #define  LLD "%lld"
+#define  LLD_FORMAT "lld"
 #endif
 
 
@@ -78,7 +81,7 @@
 #include <gd.h>
 #include <gdfonts.h>
 
-char *VERSION = "2.10.7";
+char *VERSION = "2.10.12";
 char *program,*router,*routerpath;
 int histvalid;
 
@@ -217,7 +220,7 @@ for debuging
       } while (n < histvalid && nextnow < history[n].time);\
 \
       if (avc != steptime) {\
-       fprintf(stderr,"ERROR: StepTime does not match Avc %8llu. Please Report this.\n", avc);\
+       fprintf(stderr,"ERROR: StepTime does not match Avc %8" LLD_FORMAT ". Please Report this.\n", avc);\
       }\
 \
       inr /= avc; outr /= avc;\
@@ -609,15 +612,17 @@ int peak;
     }
     gdImageInterlace(graph, 1); 
     
+    /* do NOT delete the out variables. they are dummies, but the actual color
+       allocation for the brush is essential */
     i_major = gdImageColorAllocate(graph,c_major);
     i_in = gdImageColorAllocate(graph,col_in[0], col_in[1], col_in[2]);
-    i_out = gdImageColorAllocate(brush_out,col_out[0], col_out[1], col_out[2]);
+    i_out = gdImageColorAllocate(brush_out,col_out[0], col_out[1], col_out[2]);        
     i_grid = gdImageColorAllocate(graph,c_grid );
     i_inm = gdImageColorAllocate(graph,col_inm[0], col_inm[1], col_inm[2]);
     i_outm = gdImageColorAllocate(brush_outm,col_outm[0], col_outm[1], col_outm[2]);
     i_outp = gdImageColorAllocate(brush_outp,col_outp[0], col_outp[1], col_outp[2]);
     i_outpg = gdImageColorAllocate(graph,col_outp[0], col_outp[1], col_outp[2]);
-    
+        
     /* draw the image border */
    if (!(options & OPTION_NOBORDER)) {
     gdImageLine(graph,0,0,XSIZE-1,0,i_light);
@@ -698,7 +703,7 @@ int peak;
 
       }
 	  gdImageString(graph, gdFontSmall,
-              xtr(maxx)-gdFontSmall->w*strlen(pngdate), 1,
+              (81+maxx*xscale)-gdFontSmall->w*strlen(pngdate), 1,
 		      (unsigned char*)pngdate, i_grid);
  	} 
   
